==> ixnetwork_restpy-1.1.4.tar.gz: ixnetwork_restpy-1.1.4/ixnetwork_restpy/testplatform/sessions/ixnetwork/globals/statistics/advanced/customgraph/customgraph.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files
if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class CustomGraph(Base):
    """This node contains Custom Graph Settings.
    The CustomGraph class encapsulates a required customGraph resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = 'customGraph'
    _SDM_ATT_MAP = {
        'MaxNumberOfStatsPerCustomGraph': 'maxNumberOfStatsPerCustomGraph',
    }
    _SDM_ENUM_MAP = {
    }

    def __init__(self, parent, list_op=False):
        super(CustomGraph, self).__init__(parent, list_op)

    @property
    def MaxNumberOfStatsPerCustomGraph(self):
        # type: () -> int
        """
        Returns
        -------
        - number: The maximum number of stats a custom graph can have. The range is 1 - 256.
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaxNumberOfStatsPerCustomGraph'])
    @MaxNumberOfStatsPerCustomGraph.setter
    def MaxNumberOfStatsPerCustomGraph(self, value):
        # type: (int) -> None
        self._set_attribute(self._SDM_ATT_MAP['MaxNumberOfStatsPerCustomGraph'], value)

    def update(self, MaxNumberOfStatsPerCustomGraph=None):
        # type: (int) -> CustomGraph
        """Updates customGraph resource on the server.

        Args
        ----
        - MaxNumberOfStatsPerCustomGraph (number): The maximum number of stats a custom graph can have. The range is 1 - 256.

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, MaxNumberOfStatsPerCustomGraph=None):
        # type: (int) -> CustomGraph
        """Finds and retrieves customGraph resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve customGraph resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all customGraph resources from the server.

        Args
        ----
        - MaxNumberOfStatsPerCustomGraph (number): The maximum number of stats a custom graph can have. The range is 1 - 256.

        Returns
        -------
        - self: This instance with matching customGraph resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of customGraph data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the customGraph resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)

==> ixnetwork_restpy-1.1.5.tar.gz: ixnetwork_restpy-1.1.5/ixnetwork_restpy/testplatform/sessions/ixnetwork/globals/statistics/advanced/customgraph/customgraph.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files

if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class CustomGraph(Base):
    """This node contains Custom Graph Settings.
    The CustomGraph class encapsulates a required customGraph resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = "customGraph"
    _SDM_ATT_MAP = {
        "MaxNumberOfStatsPerCustomGraph": "maxNumberOfStatsPerCustomGraph",
    }
    _SDM_ENUM_MAP = {}

    def __init__(self, parent, list_op=False):
        super(CustomGraph, self).__init__(parent, list_op)

    @property
    def MaxNumberOfStatsPerCustomGraph(self):
        # type: () -> int
        """
        Returns
        -------
        - number: The maximum number of stats a custom graph can have. The range is 1 - 256.
        """
        return self._get_attribute(self._SDM_ATT_MAP["MaxNumberOfStatsPerCustomGraph"])

    @MaxNumberOfStatsPerCustomGraph.setter
    def MaxNumberOfStatsPerCustomGraph(self, value):
        # type: (int) -> None
        self._set_attribute(self._SDM_ATT_MAP["MaxNumberOfStatsPerCustomGraph"], value)

    def update(self, MaxNumberOfStatsPerCustomGraph=None):
        # type: (int) -> CustomGraph
        """Updates customGraph resource on the server.

        Args
        ----
        - MaxNumberOfStatsPerCustomGraph (number): The maximum number of stats a custom graph can have. The range is 1 - 256.

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, MaxNumberOfStatsPerCustomGraph=None):
        # type: (int) -> CustomGraph
        """Finds and retrieves customGraph resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve customGraph resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all customGraph resources from the server.

        Args
        ----
        - MaxNumberOfStatsPerCustomGraph (number): The maximum number of stats a custom graph can have. The range is 1 - 256.

        Returns
        -------
        - self: This instance with matching customGraph resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of customGraph data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the customGraph resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)
